# cheval: Simple Configurations with Zero Redundancy

`cheval` is a lightweight package that allows you to configure your classes with minimum
boilerplate. Configurations are easy to understand, quick to write, and intuitive to work with.

## Requirements

Python 3.6+

## Installation

The recommended installation method is pip-installing into a virtual environment:

```bash
$ python -m pip install git+ssh://git@github.com/rpeloff/cheval.git
```

TODO(rpeloff): update once we have fully moved to PyPi

## `cheval` by Example

TODO(rpeloff): populate README with concrete examples

## License

This project is licensed under the terms of the
[Apache License 2.0](https://choosealicense.com/licenses/apache-2.0/) license.

## Citing cheval

If you use Cheval in your research please use the following BibTeX entry:

```BibTeX
@Misc{Eloff2022cheval,
  author =       {Ryan Eloff},
  title =        {cheval},
  howpublished = {Github},
  year =         {2022},
  url =          {https://github.com/rpeloff/cheval}
}
```